# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs

    The version of the OpenAPI document: v1.30.2.4939
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictInt, StrictStr
from typing import Optional

from prowlarr.api_client import ApiClient, RequestSerialized
from prowlarr.api_response import ApiResponse
from prowlarr.rest import RESTResponseType


class NewznabApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_indexer_download(
        self,
        id: StrictInt,
        link: Optional[StrictStr] = None,
        file: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """get_indexer_download


        :param id: (required)
        :type id: int
        :param link:
        :type link: str
        :param file:
        :type file: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_indexer_download_serialize(
            id=id,
            link=link,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_indexer_download_with_http_info(
        self,
        id: StrictInt,
        link: Optional[StrictStr] = None,
        file: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """get_indexer_download


        :param id: (required)
        :type id: int
        :param link:
        :type link: str
        :param file:
        :type file: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_indexer_download_serialize(
            id=id,
            link=link,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_indexer_download_without_preload_content(
        self,
        id: StrictInt,
        link: Optional[StrictStr] = None,
        file: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_indexer_download


        :param id: (required)
        :type id: int
        :param link:
        :type link: str
        :param file:
        :type file: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_indexer_download_serialize(
            id=id,
            link=link,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_indexer_download_serialize(
        self,
        id,
        link,
        file,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        if link is not None:
            
            _query_params.append(('link', link))
            
        if file is not None:
            
            _query_params.append(('file', file))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'apikey', 
            'X-Api-Key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/indexer/{id}/download',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_indexer_newznab(
        self,
        id: StrictInt,
        t: Optional[StrictStr] = None,
        q: Optional[StrictStr] = None,
        cat: Optional[StrictStr] = None,
        imdbid: Optional[StrictStr] = None,
        tmdbid: Optional[StrictInt] = None,
        extended: Optional[StrictStr] = None,
        limit: Optional[StrictInt] = None,
        offset: Optional[StrictInt] = None,
        minage: Optional[StrictInt] = None,
        maxage: Optional[StrictInt] = None,
        minsize: Optional[StrictInt] = None,
        maxsize: Optional[StrictInt] = None,
        rid: Optional[StrictInt] = None,
        tvmazeid: Optional[StrictInt] = None,
        traktid: Optional[StrictInt] = None,
        tvdbid: Optional[StrictInt] = None,
        doubanid: Optional[StrictInt] = None,
        season: Optional[StrictInt] = None,
        ep: Optional[StrictStr] = None,
        album: Optional[StrictStr] = None,
        artist: Optional[StrictStr] = None,
        label: Optional[StrictStr] = None,
        track: Optional[StrictStr] = None,
        year: Optional[StrictInt] = None,
        genre: Optional[StrictStr] = None,
        author: Optional[StrictStr] = None,
        title: Optional[StrictStr] = None,
        publisher: Optional[StrictStr] = None,
        configured: Optional[StrictStr] = None,
        source: Optional[StrictStr] = None,
        host: Optional[StrictStr] = None,
        server: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """get_indexer_newznab


        :param id: (required)
        :type id: int
        :param t:
        :type t: str
        :param q:
        :type q: str
        :param cat:
        :type cat: str
        :param imdbid:
        :type imdbid: str
        :param tmdbid:
        :type tmdbid: int
        :param extended:
        :type extended: str
        :param limit:
        :type limit: int
        :param offset:
        :type offset: int
        :param minage:
        :type minage: int
        :param maxage:
        :type maxage: int
        :param minsize:
        :type minsize: int
        :param maxsize:
        :type maxsize: int
        :param rid:
        :type rid: int
        :param tvmazeid:
        :type tvmazeid: int
        :param traktid:
        :type traktid: int
        :param tvdbid:
        :type tvdbid: int
        :param doubanid:
        :type doubanid: int
        :param season:
        :type season: int
        :param ep:
        :type ep: str
        :param album:
        :type album: str
        :param artist:
        :type artist: str
        :param label:
        :type label: str
        :param track:
        :type track: str
        :param year:
        :type year: int
        :param genre:
        :type genre: str
        :param author:
        :type author: str
        :param title:
        :type title: str
        :param publisher:
        :type publisher: str
        :param configured:
        :type configured: str
        :param source:
        :type source: str
        :param host:
        :type host: str
        :param server:
        :type server: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_indexer_newznab_serialize(
            id=id,
            t=t,
            q=q,
            cat=cat,
            imdbid=imdbid,
            tmdbid=tmdbid,
            extended=extended,
            limit=limit,
            offset=offset,
            minage=minage,
            maxage=maxage,
            minsize=minsize,
            maxsize=maxsize,
            rid=rid,
            tvmazeid=tvmazeid,
            traktid=traktid,
            tvdbid=tvdbid,
            doubanid=doubanid,
            season=season,
            ep=ep,
            album=album,
            artist=artist,
            label=label,
            track=track,
            year=year,
            genre=genre,
            author=author,
            title=title,
            publisher=publisher,
            configured=configured,
            source=source,
            host=host,
            server=server,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_indexer_newznab_with_http_info(
        self,
        id: StrictInt,
        t: Optional[StrictStr] = None,
        q: Optional[StrictStr] = None,
        cat: Optional[StrictStr] = None,
        imdbid: Optional[StrictStr] = None,
        tmdbid: Optional[StrictInt] = None,
        extended: Optional[StrictStr] = None,
        limit: Optional[StrictInt] = None,
        offset: Optional[StrictInt] = None,
        minage: Optional[StrictInt] = None,
        maxage: Optional[StrictInt] = None,
        minsize: Optional[StrictInt] = None,
        maxsize: Optional[StrictInt] = None,
        rid: Optional[StrictInt] = None,
        tvmazeid: Optional[StrictInt] = None,
        traktid: Optional[StrictInt] = None,
        tvdbid: Optional[StrictInt] = None,
        doubanid: Optional[StrictInt] = None,
        season: Optional[StrictInt] = None,
        ep: Optional[StrictStr] = None,
        album: Optional[StrictStr] = None,
        artist: Optional[StrictStr] = None,
        label: Optional[StrictStr] = None,
        track: Optional[StrictStr] = None,
        year: Optional[StrictInt] = None,
        genre: Optional[StrictStr] = None,
        author: Optional[StrictStr] = None,
        title: Optional[StrictStr] = None,
        publisher: Optional[StrictStr] = None,
        configured: Optional[StrictStr] = None,
        source: Optional[StrictStr] = None,
        host: Optional[StrictStr] = None,
        server: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """get_indexer_newznab


        :param id: (required)
        :type id: int
        :param t:
        :type t: str
        :param q:
        :type q: str
        :param cat:
        :type cat: str
        :param imdbid:
        :type imdbid: str
        :param tmdbid:
        :type tmdbid: int
        :param extended:
        :type extended: str
        :param limit:
        :type limit: int
        :param offset:
        :type offset: int
        :param minage:
        :type minage: int
        :param maxage:
        :type maxage: int
        :param minsize:
        :type minsize: int
        :param maxsize:
        :type maxsize: int
        :param rid:
        :type rid: int
        :param tvmazeid:
        :type tvmazeid: int
        :param traktid:
        :type traktid: int
        :param tvdbid:
        :type tvdbid: int
        :param doubanid:
        :type doubanid: int
        :param season:
        :type season: int
        :param ep:
        :type ep: str
        :param album:
        :type album: str
        :param artist:
        :type artist: str
        :param label:
        :type label: str
        :param track:
        :type track: str
        :param year:
        :type year: int
        :param genre:
        :type genre: str
        :param author:
        :type author: str
        :param title:
        :type title: str
        :param publisher:
        :type publisher: str
        :param configured:
        :type configured: str
        :param source:
        :type source: str
        :param host:
        :type host: str
        :param server:
        :type server: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_indexer_newznab_serialize(
            id=id,
            t=t,
            q=q,
            cat=cat,
            imdbid=imdbid,
            tmdbid=tmdbid,
            extended=extended,
            limit=limit,
            offset=offset,
            minage=minage,
            maxage=maxage,
            minsize=minsize,
            maxsize=maxsize,
            rid=rid,
            tvmazeid=tvmazeid,
            traktid=traktid,
            tvdbid=tvdbid,
            doubanid=doubanid,
            season=season,
            ep=ep,
            album=album,
            artist=artist,
            label=label,
            track=track,
            year=year,
            genre=genre,
            author=author,
            title=title,
            publisher=publisher,
            configured=configured,
            source=source,
            host=host,
            server=server,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_indexer_newznab_without_preload_content(
        self,
        id: StrictInt,
        t: Optional[StrictStr] = None,
        q: Optional[StrictStr] = None,
        cat: Optional[StrictStr] = None,
        imdbid: Optional[StrictStr] = None,
        tmdbid: Optional[StrictInt] = None,
        extended: Optional[StrictStr] = None,
        limit: Optional[StrictInt] = None,
        offset: Optional[StrictInt] = None,
        minage: Optional[StrictInt] = None,
        maxage: Optional[StrictInt] = None,
        minsize: Optional[StrictInt] = None,
        maxsize: Optional[StrictInt] = None,
        rid: Optional[StrictInt] = None,
        tvmazeid: Optional[StrictInt] = None,
        traktid: Optional[StrictInt] = None,
        tvdbid: Optional[StrictInt] = None,
        doubanid: Optional[StrictInt] = None,
        season: Optional[StrictInt] = None,
        ep: Optional[StrictStr] = None,
        album: Optional[StrictStr] = None,
        artist: Optional[StrictStr] = None,
        label: Optional[StrictStr] = None,
        track: Optional[StrictStr] = None,
        year: Optional[StrictInt] = None,
        genre: Optional[StrictStr] = None,
        author: Optional[StrictStr] = None,
        title: Optional[StrictStr] = None,
        publisher: Optional[StrictStr] = None,
        configured: Optional[StrictStr] = None,
        source: Optional[StrictStr] = None,
        host: Optional[StrictStr] = None,
        server: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_indexer_newznab


        :param id: (required)
        :type id: int
        :param t:
        :type t: str
        :param q:
        :type q: str
        :param cat:
        :type cat: str
        :param imdbid:
        :type imdbid: str
        :param tmdbid:
        :type tmdbid: int
        :param extended:
        :type extended: str
        :param limit:
        :type limit: int
        :param offset:
        :type offset: int
        :param minage:
        :type minage: int
        :param maxage:
        :type maxage: int
        :param minsize:
        :type minsize: int
        :param maxsize:
        :type maxsize: int
        :param rid:
        :type rid: int
        :param tvmazeid:
        :type tvmazeid: int
        :param traktid:
        :type traktid: int
        :param tvdbid:
        :type tvdbid: int
        :param doubanid:
        :type doubanid: int
        :param season:
        :type season: int
        :param ep:
        :type ep: str
        :param album:
        :type album: str
        :param artist:
        :type artist: str
        :param label:
        :type label: str
        :param track:
        :type track: str
        :param year:
        :type year: int
        :param genre:
        :type genre: str
        :param author:
        :type author: str
        :param title:
        :type title: str
        :param publisher:
        :type publisher: str
        :param configured:
        :type configured: str
        :param source:
        :type source: str
        :param host:
        :type host: str
        :param server:
        :type server: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_indexer_newznab_serialize(
            id=id,
            t=t,
            q=q,
            cat=cat,
            imdbid=imdbid,
            tmdbid=tmdbid,
            extended=extended,
            limit=limit,
            offset=offset,
            minage=minage,
            maxage=maxage,
            minsize=minsize,
            maxsize=maxsize,
            rid=rid,
            tvmazeid=tvmazeid,
            traktid=traktid,
            tvdbid=tvdbid,
            doubanid=doubanid,
            season=season,
            ep=ep,
            album=album,
            artist=artist,
            label=label,
            track=track,
            year=year,
            genre=genre,
            author=author,
            title=title,
            publisher=publisher,
            configured=configured,
            source=source,
            host=host,
            server=server,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '2XX': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_indexer_newznab_serialize(
        self,
        id,
        t,
        q,
        cat,
        imdbid,
        tmdbid,
        extended,
        limit,
        offset,
        minage,
        maxage,
        minsize,
        maxsize,
        rid,
        tvmazeid,
        traktid,
        tvdbid,
        doubanid,
        season,
        ep,
        album,
        artist,
        label,
        track,
        year,
        genre,
        author,
        title,
        publisher,
        configured,
        source,
        host,
        server,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        if t is not None:
            
            _query_params.append(('t', t))
            
        if q is not None:
            
            _query_params.append(('q', q))
            
        if cat is not None:
            
            _query_params.append(('cat', cat))
            
        if imdbid is not None:
            
            _query_params.append(('imdbid', imdbid))
            
        if tmdbid is not None:
            
            _query_params.append(('tmdbid', tmdbid))
            
        if extended is not None:
            
            _query_params.append(('extended', extended))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if minage is not None:
            
            _query_params.append(('minage', minage))
            
        if maxage is not None:
            
            _query_params.append(('maxage', maxage))
            
        if minsize is not None:
            
            _query_params.append(('minsize', minsize))
            
        if maxsize is not None:
            
            _query_params.append(('maxsize', maxsize))
            
        if rid is not None:
            
            _query_params.append(('rid', rid))
            
        if tvmazeid is not None:
            
            _query_params.append(('tvmazeid', tvmazeid))
            
        if traktid is not None:
            
            _query_params.append(('traktid', traktid))
            
        if tvdbid is not None:
            
            _query_params.append(('tvdbid', tvdbid))
            
        if doubanid is not None:
            
            _query_params.append(('doubanid', doubanid))
            
        if season is not None:
            
            _query_params.append(('season', season))
            
        if ep is not None:
            
            _query_params.append(('ep', ep))
            
        if album is not None:
            
            _query_params.append(('album', album))
            
        if artist is not None:
            
            _query_params.append(('artist', artist))
            
        if label is not None:
            
            _query_params.append(('label', label))
            
        if track is not None:
            
            _query_params.append(('track', track))
            
        if year is not None:
            
            _query_params.append(('year', year))
            
        if genre is not None:
            
            _query_params.append(('genre', genre))
            
        if author is not None:
            
            _query_params.append(('author', author))
            
        if title is not None:
            
            _query_params.append(('title', title))
            
        if publisher is not None:
            
            _query_params.append(('publisher', publisher))
            
        if configured is not None:
            
            _query_params.append(('configured', configured))
            
        if source is not None:
            
            _query_params.append(('source', source))
            
        if host is not None:
            
            _query_params.append(('host', host))
            
        if server is not None:
            
            _query_params.append(('server', server))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'apikey', 
            'X-Api-Key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/indexer/{id}/newznab',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs

    The version of the OpenAPI document: v1.30.2.4939
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, Optional
from typing import Optional, Set
from typing_extensions import Self

class UiConfigResource(BaseModel):
    """
    UiConfigResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    first_day_of_week: Optional[StrictInt] = Field(default=None, alias="firstDayOfWeek")
    calendar_week_column_header: Optional[StrictStr] = Field(default=None, alias="calendarWeekColumnHeader")
    short_date_format: Optional[StrictStr] = Field(default=None, alias="shortDateFormat")
    long_date_format: Optional[StrictStr] = Field(default=None, alias="longDateFormat")
    time_format: Optional[StrictStr] = Field(default=None, alias="timeFormat")
    show_relative_dates: Optional[StrictBool] = Field(default=None, alias="showRelativeDates")
    enable_color_impaired_mode: Optional[StrictBool] = Field(default=None, alias="enableColorImpairedMode")
    ui_language: Optional[StrictStr] = Field(default=None, alias="uiLanguage")
    theme: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["id", "firstDayOfWeek", "calendarWeekColumnHeader", "shortDateFormat", "longDateFormat", "timeFormat", "showRelativeDates", "enableColorImpairedMode", "uiLanguage", "theme"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UiConfigResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if calendar_week_column_header (nullable) is None
        # and model_fields_set contains the field
        if self.calendar_week_column_header is None and "calendar_week_column_header" in self.model_fields_set:
            _dict['calendarWeekColumnHeader'] = None

        # set to None if short_date_format (nullable) is None
        # and model_fields_set contains the field
        if self.short_date_format is None and "short_date_format" in self.model_fields_set:
            _dict['shortDateFormat'] = None

        # set to None if long_date_format (nullable) is None
        # and model_fields_set contains the field
        if self.long_date_format is None and "long_date_format" in self.model_fields_set:
            _dict['longDateFormat'] = None

        # set to None if time_format (nullable) is None
        # and model_fields_set contains the field
        if self.time_format is None and "time_format" in self.model_fields_set:
            _dict['timeFormat'] = None

        # set to None if ui_language (nullable) is None
        # and model_fields_set contains the field
        if self.ui_language is None and "ui_language" in self.model_fields_set:
            _dict['uiLanguage'] = None

        # set to None if theme (nullable) is None
        # and model_fields_set contains the field
        if self.theme is None and "theme" in self.model_fields_set:
            _dict['theme'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UiConfigResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "firstDayOfWeek": obj.get("firstDayOfWeek"),
            "calendarWeekColumnHeader": obj.get("calendarWeekColumnHeader"),
            "shortDateFormat": obj.get("shortDateFormat"),
            "longDateFormat": obj.get("longDateFormat"),
            "timeFormat": obj.get("timeFormat"),
            "showRelativeDates": obj.get("showRelativeDates"),
            "enableColorImpairedMode": obj.get("enableColorImpairedMode"),
            "uiLanguage": obj.get("uiLanguage"),
            "theme": obj.get("theme")
        })
        return _obj





# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs

    The version of the OpenAPI document: v1.30.2.4939
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, Optional
from prowlarr.models.update_changes import UpdateChanges
from typing import Optional, Set
from typing_extensions import Self

class UpdateResource(BaseModel):
    """
    UpdateResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    version: Optional[StrictStr] = None
    branch: Optional[StrictStr] = None
    release_date: Optional[datetime] = Field(default=None, alias="releaseDate")
    file_name: Optional[StrictStr] = Field(default=None, alias="fileName")
    url: Optional[StrictStr] = None
    installed: Optional[StrictBool] = None
    installed_on: Optional[datetime] = Field(default=None, alias="installedOn")
    installable: Optional[StrictBool] = None
    latest: Optional[StrictBool] = None
    changes: Optional[UpdateChanges] = None
    hash: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["id", "version", "branch", "releaseDate", "fileName", "url", "installed", "installedOn", "installable", "latest", "changes", "hash"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UpdateResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of changes
        if self.changes:
            _dict['changes'] = self.changes.to_dict()
        # set to None if version (nullable) is None
        # and model_fields_set contains the field
        if self.version is None and "version" in self.model_fields_set:
            _dict['version'] = None

        # set to None if branch (nullable) is None
        # and model_fields_set contains the field
        if self.branch is None and "branch" in self.model_fields_set:
            _dict['branch'] = None

        # set to None if file_name (nullable) is None
        # and model_fields_set contains the field
        if self.file_name is None and "file_name" in self.model_fields_set:
            _dict['fileName'] = None

        # set to None if url (nullable) is None
        # and model_fields_set contains the field
        if self.url is None and "url" in self.model_fields_set:
            _dict['url'] = None

        # set to None if installed_on (nullable) is None
        # and model_fields_set contains the field
        if self.installed_on is None and "installed_on" in self.model_fields_set:
            _dict['installedOn'] = None

        # set to None if hash (nullable) is None
        # and model_fields_set contains the field
        if self.hash is None and "hash" in self.model_fields_set:
            _dict['hash'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UpdateResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "version": obj.get("version"),
            "branch": obj.get("branch"),
            "releaseDate": obj.get("releaseDate"),
            "fileName": obj.get("fileName"),
            "url": obj.get("url"),
            "installed": obj.get("installed"),
            "installedOn": obj.get("installedOn"),
            "installable": obj.get("installable"),
            "latest": obj.get("latest"),
            "changes": UpdateChanges.from_dict(obj["changes"]) if obj.get("changes") is not None else None,
            "hash": obj.get("hash")
        })
        return _obj





# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs

    The version of the OpenAPI document: v1.30.2.4939
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AuthenticationRequiredType(str, Enum):
    """
    AuthenticationRequiredType
    """

    """
    allowed enum values
    """
    ENABLED = 'enabled'
    DISABLEDFORLOCALADDRESSES = 'disabledForLocalAddresses'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AuthenticationRequiredType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs

    The version of the OpenAPI document: v1.30.2.4939
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from prowlarr.models.contract_field import ContractField
from prowlarr.models.download_protocol import DownloadProtocol
from prowlarr.models.indexer_capability_resource import IndexerCapabilityResource
from prowlarr.models.indexer_privacy import IndexerPrivacy
from prowlarr.models.indexer_status_resource import IndexerStatusResource
from prowlarr.models.provider_message import ProviderMessage
from typing import Optional, Set
from typing_extensions import Self

class IndexerResource(BaseModel):
    """
    IndexerResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    name: Optional[StrictStr] = None
    fields: Optional[List[ContractField]] = None
    implementation_name: Optional[StrictStr] = Field(default=None, alias="implementationName")
    implementation: Optional[StrictStr] = None
    config_contract: Optional[StrictStr] = Field(default=None, alias="configContract")
    info_link: Optional[StrictStr] = Field(default=None, alias="infoLink")
    message: Optional[ProviderMessage] = None
    tags: Optional[List[StrictInt]] = None
    presets: Optional[List[IndexerResource]] = None
    indexer_urls: Optional[List[StrictStr]] = Field(default=None, alias="indexerUrls")
    legacy_urls: Optional[List[StrictStr]] = Field(default=None, alias="legacyUrls")
    definition_name: Optional[StrictStr] = Field(default=None, alias="definitionName")
    description: Optional[StrictStr] = None
    language: Optional[StrictStr] = None
    encoding: Optional[StrictStr] = None
    enable: Optional[StrictBool] = None
    redirect: Optional[StrictBool] = None
    supports_rss: Optional[StrictBool] = Field(default=None, alias="supportsRss")
    supports_search: Optional[StrictBool] = Field(default=None, alias="supportsSearch")
    supports_redirect: Optional[StrictBool] = Field(default=None, alias="supportsRedirect")
    supports_pagination: Optional[StrictBool] = Field(default=None, alias="supportsPagination")
    app_profile_id: Optional[StrictInt] = Field(default=None, alias="appProfileId")
    protocol: Optional[DownloadProtocol] = None
    privacy: Optional[IndexerPrivacy] = None
    capabilities: Optional[IndexerCapabilityResource] = None
    priority: Optional[StrictInt] = None
    download_client_id: Optional[StrictInt] = Field(default=None, alias="downloadClientId")
    added: Optional[datetime] = None
    status: Optional[IndexerStatusResource] = None
    sort_name: Optional[StrictStr] = Field(default=None, alias="sortName")
    __properties: ClassVar[List[str]] = ["id", "name", "fields", "implementationName", "implementation", "configContract", "infoLink", "message", "tags", "presets", "indexerUrls", "legacyUrls", "definitionName", "description", "language", "encoding", "enable", "redirect", "supportsRss", "supportsSearch", "supportsRedirect", "supportsPagination", "appProfileId", "protocol", "privacy", "capabilities", "priority", "downloadClientId", "added", "status", "sortName"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IndexerResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in fields (list)
        _items = []
        if self.fields:
            for _item_fields in self.fields:
                if _item_fields:
                    _items.append(_item_fields.to_dict())
            _dict['fields'] = _items
        # override the default output from pydantic by calling `to_dict()` of message
        if self.message:
            _dict['message'] = self.message.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in presets (list)
        _items = []
        if self.presets:
            for _item_presets in self.presets:
                if _item_presets:
                    _items.append(_item_presets.to_dict())
            _dict['presets'] = _items
        # override the default output from pydantic by calling `to_dict()` of capabilities
        if self.capabilities:
            _dict['capabilities'] = self.capabilities.to_dict()
        # override the default output from pydantic by calling `to_dict()` of status
        if self.status:
            _dict['status'] = self.status.to_dict()
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if fields (nullable) is None
        # and model_fields_set contains the field
        if self.fields is None and "fields" in self.model_fields_set:
            _dict['fields'] = None

        # set to None if implementation_name (nullable) is None
        # and model_fields_set contains the field
        if self.implementation_name is None and "implementation_name" in self.model_fields_set:
            _dict['implementationName'] = None

        # set to None if implementation (nullable) is None
        # and model_fields_set contains the field
        if self.implementation is None and "implementation" in self.model_fields_set:
            _dict['implementation'] = None

        # set to None if config_contract (nullable) is None
        # and model_fields_set contains the field
        if self.config_contract is None and "config_contract" in self.model_fields_set:
            _dict['configContract'] = None

        # set to None if info_link (nullable) is None
        # and model_fields_set contains the field
        if self.info_link is None and "info_link" in self.model_fields_set:
            _dict['infoLink'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        # set to None if presets (nullable) is None
        # and model_fields_set contains the field
        if self.presets is None and "presets" in self.model_fields_set:
            _dict['presets'] = None

        # set to None if indexer_urls (nullable) is None
        # and model_fields_set contains the field
        if self.indexer_urls is None and "indexer_urls" in self.model_fields_set:
            _dict['indexerUrls'] = None

        # set to None if legacy_urls (nullable) is None
        # and model_fields_set contains the field
        if self.legacy_urls is None and "legacy_urls" in self.model_fields_set:
            _dict['legacyUrls'] = None

        # set to None if definition_name (nullable) is None
        # and model_fields_set contains the field
        if self.definition_name is None and "definition_name" in self.model_fields_set:
            _dict['definitionName'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if language (nullable) is None
        # and model_fields_set contains the field
        if self.language is None and "language" in self.model_fields_set:
            _dict['language'] = None

        # set to None if encoding (nullable) is None
        # and model_fields_set contains the field
        if self.encoding is None and "encoding" in self.model_fields_set:
            _dict['encoding'] = None

        # set to None if sort_name (nullable) is None
        # and model_fields_set contains the field
        if self.sort_name is None and "sort_name" in self.model_fields_set:
            _dict['sortName'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IndexerResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "fields": [ContractField.from_dict(_item) for _item in obj["fields"]] if obj.get("fields") is not None else None,
            "implementationName": obj.get("implementationName"),
            "implementation": obj.get("implementation"),
            "configContract": obj.get("configContract"),
            "infoLink": obj.get("infoLink"),
            "message": ProviderMessage.from_dict(obj["message"]) if obj.get("message") is not None else None,
            "tags": obj.get("tags"),
            "presets": [IndexerResource.from_dict(_item) for _item in obj["presets"]] if obj.get("presets") is not None else None,
            "indexerUrls": obj.get("indexerUrls"),
            "legacyUrls": obj.get("legacyUrls"),
            "definitionName": obj.get("definitionName"),
            "description": obj.get("description"),
            "language": obj.get("language"),
            "encoding": obj.get("encoding"),
            "enable": obj.get("enable"),
            "redirect": obj.get("redirect"),
            "supportsRss": obj.get("supportsRss"),
            "supportsSearch": obj.get("supportsSearch"),
            "supportsRedirect": obj.get("supportsRedirect"),
            "supportsPagination": obj.get("supportsPagination"),
            "appProfileId": obj.get("appProfileId"),
            "protocol": obj.get("protocol"),
            "privacy": obj.get("privacy"),
            "capabilities": IndexerCapabilityResource.from_dict(obj["capabilities"]) if obj.get("capabilities") is not None else None,
            "priority": obj.get("priority"),
            "downloadClientId": obj.get("downloadClientId"),
            "added": obj.get("added"),
            "status": IndexerStatusResource.from_dict(obj["status"]) if obj.get("status") is not None else None,
            "sortName": obj.get("sortName")
        })
        return _obj

# TODO: Rewrite to not use raise_errors
IndexerResource.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs

    The version of the OpenAPI document: v1.30.2.4939
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, Optional
from prowlarr.models.authentication_type import AuthenticationType
from prowlarr.models.database_type import DatabaseType
from prowlarr.models.runtime_mode import RuntimeMode
from prowlarr.models.update_mechanism import UpdateMechanism
from typing import Optional, Set
from typing_extensions import Self

class SystemResource(BaseModel):
    """
    SystemResource
    """ # noqa: E501
    app_name: Optional[StrictStr] = Field(default=None, alias="appName")
    instance_name: Optional[StrictStr] = Field(default=None, alias="instanceName")
    version: Optional[StrictStr] = None
    build_time: Optional[datetime] = Field(default=None, alias="buildTime")
    is_debug: Optional[StrictBool] = Field(default=None, alias="isDebug")
    is_production: Optional[StrictBool] = Field(default=None, alias="isProduction")
    is_admin: Optional[StrictBool] = Field(default=None, alias="isAdmin")
    is_user_interactive: Optional[StrictBool] = Field(default=None, alias="isUserInteractive")
    startup_path: Optional[StrictStr] = Field(default=None, alias="startupPath")
    app_data: Optional[StrictStr] = Field(default=None, alias="appData")
    os_name: Optional[StrictStr] = Field(default=None, alias="osName")
    os_version: Optional[StrictStr] = Field(default=None, alias="osVersion")
    is_net_core: Optional[StrictBool] = Field(default=None, alias="isNetCore")
    is_linux: Optional[StrictBool] = Field(default=None, alias="isLinux")
    is_osx: Optional[StrictBool] = Field(default=None, alias="isOsx")
    is_windows: Optional[StrictBool] = Field(default=None, alias="isWindows")
    is_docker: Optional[StrictBool] = Field(default=None, alias="isDocker")
    mode: Optional[RuntimeMode] = None
    branch: Optional[StrictStr] = None
    database_type: Optional[DatabaseType] = Field(default=None, alias="databaseType")
    database_version: Optional[StrictStr] = Field(default=None, alias="databaseVersion")
    authentication: Optional[AuthenticationType] = None
    migration_version: Optional[StrictInt] = Field(default=None, alias="migrationVersion")
    url_base: Optional[StrictStr] = Field(default=None, alias="urlBase")
    runtime_version: Optional[StrictStr] = Field(default=None, alias="runtimeVersion")
    runtime_name: Optional[StrictStr] = Field(default=None, alias="runtimeName")
    start_time: Optional[datetime] = Field(default=None, alias="startTime")
    package_version: Optional[StrictStr] = Field(default=None, alias="packageVersion")
    package_author: Optional[StrictStr] = Field(default=None, alias="packageAuthor")
    package_update_mechanism: Optional[UpdateMechanism] = Field(default=None, alias="packageUpdateMechanism")
    package_update_mechanism_message: Optional[StrictStr] = Field(default=None, alias="packageUpdateMechanismMessage")
    __properties: ClassVar[List[str]] = ["appName", "instanceName", "version", "buildTime", "isDebug", "isProduction", "isAdmin", "isUserInteractive", "startupPath", "appData", "osName", "osVersion", "isNetCore", "isLinux", "isOsx", "isWindows", "isDocker", "mode", "branch", "databaseType", "databaseVersion", "authentication", "migrationVersion", "urlBase", "runtimeVersion", "runtimeName", "startTime", "packageVersion", "packageAuthor", "packageUpdateMechanism", "packageUpdateMechanismMessage"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SystemResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if app_name (nullable) is None
        # and model_fields_set contains the field
        if self.app_name is None and "app_name" in self.model_fields_set:
            _dict['appName'] = None

        # set to None if instance_name (nullable) is None
        # and model_fields_set contains the field
        if self.instance_name is None and "instance_name" in self.model_fields_set:
            _dict['instanceName'] = None

        # set to None if version (nullable) is None
        # and model_fields_set contains the field
        if self.version is None and "version" in self.model_fields_set:
            _dict['version'] = None

        # set to None if startup_path (nullable) is None
        # and model_fields_set contains the field
        if self.startup_path is None and "startup_path" in self.model_fields_set:
            _dict['startupPath'] = None

        # set to None if app_data (nullable) is None
        # and model_fields_set contains the field
        if self.app_data is None and "app_data" in self.model_fields_set:
            _dict['appData'] = None

        # set to None if os_name (nullable) is None
        # and model_fields_set contains the field
        if self.os_name is None and "os_name" in self.model_fields_set:
            _dict['osName'] = None

        # set to None if os_version (nullable) is None
        # and model_fields_set contains the field
        if self.os_version is None and "os_version" in self.model_fields_set:
            _dict['osVersion'] = None

        # set to None if branch (nullable) is None
        # and model_fields_set contains the field
        if self.branch is None and "branch" in self.model_fields_set:
            _dict['branch'] = None

        # set to None if database_version (nullable) is None
        # and model_fields_set contains the field
        if self.database_version is None and "database_version" in self.model_fields_set:
            _dict['databaseVersion'] = None

        # set to None if url_base (nullable) is None
        # and model_fields_set contains the field
        if self.url_base is None and "url_base" in self.model_fields_set:
            _dict['urlBase'] = None

        # set to None if runtime_version (nullable) is None
        # and model_fields_set contains the field
        if self.runtime_version is None and "runtime_version" in self.model_fields_set:
            _dict['runtimeVersion'] = None

        # set to None if runtime_name (nullable) is None
        # and model_fields_set contains the field
        if self.runtime_name is None and "runtime_name" in self.model_fields_set:
            _dict['runtimeName'] = None

        # set to None if package_version (nullable) is None
        # and model_fields_set contains the field
        if self.package_version is None and "package_version" in self.model_fields_set:
            _dict['packageVersion'] = None

        # set to None if package_author (nullable) is None
        # and model_fields_set contains the field
        if self.package_author is None and "package_author" in self.model_fields_set:
            _dict['packageAuthor'] = None

        # set to None if package_update_mechanism_message (nullable) is None
        # and model_fields_set contains the field
        if self.package_update_mechanism_message is None and "package_update_mechanism_message" in self.model_fields_set:
            _dict['packageUpdateMechanismMessage'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SystemResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "appName": obj.get("appName"),
            "instanceName": obj.get("instanceName"),
            "version": obj.get("version"),
            "buildTime": obj.get("buildTime"),
            "isDebug": obj.get("isDebug"),
            "isProduction": obj.get("isProduction"),
            "isAdmin": obj.get("isAdmin"),
            "isUserInteractive": obj.get("isUserInteractive"),
            "startupPath": obj.get("startupPath"),
            "appData": obj.get("appData"),
            "osName": obj.get("osName"),
            "osVersion": obj.get("osVersion"),
            "isNetCore": obj.get("isNetCore"),
            "isLinux": obj.get("isLinux"),
            "isOsx": obj.get("isOsx"),
            "isWindows": obj.get("isWindows"),
            "isDocker": obj.get("isDocker"),
            "mode": obj.get("mode"),
            "branch": obj.get("branch"),
            "databaseType": obj.get("databaseType"),
            "databaseVersion": obj.get("databaseVersion"),
            "authentication": obj.get("authentication"),
            "migrationVersion": obj.get("migrationVersion"),
            "urlBase": obj.get("urlBase"),
            "runtimeVersion": obj.get("runtimeVersion"),
            "runtimeName": obj.get("runtimeName"),
            "startTime": obj.get("startTime"),
            "packageVersion": obj.get("packageVersion"),
            "packageAuthor": obj.get("packageAuthor"),
            "packageUpdateMechanism": obj.get("packageUpdateMechanism"),
            "packageUpdateMechanismMessage": obj.get("packageUpdateMechanismMessage")
        })
        return _obj





# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs

    The version of the OpenAPI document: v1.30.2.4939
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from prowlarr.models.apply_tags import ApplyTags
from typing import Optional, Set
from typing_extensions import Self

class IndexerBulkResource(BaseModel):
    """
    IndexerBulkResource
    """ # noqa: E501
    ids: Optional[List[StrictInt]] = None
    tags: Optional[List[StrictInt]] = None
    apply_tags: Optional[ApplyTags] = Field(default=None, alias="applyTags")
    enable: Optional[StrictBool] = None
    app_profile_id: Optional[StrictInt] = Field(default=None, alias="appProfileId")
    priority: Optional[StrictInt] = None
    minimum_seeders: Optional[StrictInt] = Field(default=None, alias="minimumSeeders")
    seed_ratio: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="seedRatio")
    seed_time: Optional[StrictInt] = Field(default=None, alias="seedTime")
    pack_seed_time: Optional[StrictInt] = Field(default=None, alias="packSeedTime")
    prefer_magnet_url: Optional[StrictBool] = Field(default=None, alias="preferMagnetUrl")
    __properties: ClassVar[List[str]] = ["ids", "tags", "applyTags", "enable", "appProfileId", "priority", "minimumSeeders", "seedRatio", "seedTime", "packSeedTime", "preferMagnetUrl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IndexerBulkResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if ids (nullable) is None
        # and model_fields_set contains the field
        if self.ids is None and "ids" in self.model_fields_set:
            _dict['ids'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        # set to None if enable (nullable) is None
        # and model_fields_set contains the field
        if self.enable is None and "enable" in self.model_fields_set:
            _dict['enable'] = None

        # set to None if app_profile_id (nullable) is None
        # and model_fields_set contains the field
        if self.app_profile_id is None and "app_profile_id" in self.model_fields_set:
            _dict['appProfileId'] = None

        # set to None if priority (nullable) is None
        # and model_fields_set contains the field
        if self.priority is None and "priority" in self.model_fields_set:
            _dict['priority'] = None

        # set to None if minimum_seeders (nullable) is None
        # and model_fields_set contains the field
        if self.minimum_seeders is None and "minimum_seeders" in self.model_fields_set:
            _dict['minimumSeeders'] = None

        # set to None if seed_ratio (nullable) is None
        # and model_fields_set contains the field
        if self.seed_ratio is None and "seed_ratio" in self.model_fields_set:
            _dict['seedRatio'] = None

        # set to None if seed_time (nullable) is None
        # and model_fields_set contains the field
        if self.seed_time is None and "seed_time" in self.model_fields_set:
            _dict['seedTime'] = None

        # set to None if pack_seed_time (nullable) is None
        # and model_fields_set contains the field
        if self.pack_seed_time is None and "pack_seed_time" in self.model_fields_set:
            _dict['packSeedTime'] = None

        # set to None if prefer_magnet_url (nullable) is None
        # and model_fields_set contains the field
        if self.prefer_magnet_url is None and "prefer_magnet_url" in self.model_fields_set:
            _dict['preferMagnetUrl'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IndexerBulkResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "ids": obj.get("ids"),
            "tags": obj.get("tags"),
            "applyTags": obj.get("applyTags"),
            "enable": obj.get("enable"),
            "appProfileId": obj.get("appProfileId"),
            "priority": obj.get("priority"),
            "minimumSeeders": obj.get("minimumSeeders"),
            "seedRatio": obj.get("seedRatio"),
            "seedTime": obj.get("seedTime"),
            "packSeedTime": obj.get("packSeedTime"),
            "preferMagnetUrl": obj.get("preferMagnetUrl")
        })
        return _obj


